﻿using APISamples.AdminAPI;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using System;

namespace APISamples
{
    [TestClass]
    public class AdminAPISamples
    {
        private const string UserName = "Please fill user name";
        private const string Password = "Please fill password";

        [TestMethod]
        public void GetTop10DeniedFeaturesInLast30Days()
        {
            var client = new AdminAPIClient();

            var startTime = DateTime.UtcNow.Date.AddDays(-30);
            var endTime = DateTime.UtcNow;

            var request = new DenialChartRequest
            {
                BaseInfo = CreateBaseInfo(client),

                GetTrueDenialsOnly = true,
                StartTime = new SlimDateTime()
                {
                    Year = startTime.Year,
                    Month = startTime.Month,
                    Day = startTime.Day
                },

                EndTime = new SlimDateTime()
                {
                    Year = endTime.Year,
                    Month = endTime.Month,
                    Day = endTime.Day,
                    Hour = endTime.Hour,
                    Minute = endTime.Minute,
                    Second = endTime.Second
                },
                GroupBy = "Feature"
            };

            var response = client.GetDenialsChart(request);
            Assert.IsNotNull(response);
            Assert.IsNull(response.Error);
        }

        [TestMethod]
        public void GetTop5DeniedUsersInLast30Days()
        {
            var client = new AdminAPIClient();

            var startTime = DateTime.UtcNow.Date.AddDays(-30);
            var endTime = DateTime.UtcNow;

            var request = new DenialChartRequest
            {
                BaseInfo = new RequestBaseInfo
                {
                    PagingData = new PagingData
                    {
                        StartRecord = 0,
                        NumOfRecord = 5,
                        Sort = new string[] { "value" },
                        Direction = "desc"
                    },

                    UserLocalSettings = new UserLocalSettings
                    {
                        TimezoneStandardName = "UTC",
                        ThousandsSeparator = ",",
                        DecimalSeparator = ".",
                        TimeFormat = "dd/mm/yyyy hh:mm:ss"
                    }
                },

                GetTrueDenialsOnly = true,
                StartTime = new SlimDateTime()
                {
                    Year = startTime.Year,
                    Month = startTime.Month,
                    Day = startTime.Day
                },

                EndTime = new SlimDateTime()
                {
                    Year = endTime.Year,
                    Month = endTime.Month,
                    Day = endTime.Day,
                    Hour = endTime.Hour,
                    Minute = endTime.Minute,
                    Second = endTime.Second
                },
                GroupBy = "User"
            };
            var response = client.GetDenialsChart(request);
            Assert.IsNotNull(response);
            Assert.IsNull(response.Error);
        }

        [TestMethod]
        public void GetTop10MostUsedFeaturesInLast30Days()
        {
            var client = new AdminAPIClient();

            var startTime = DateTime.UtcNow.Date.AddDays(-30);
            var endTime = DateTime.UtcNow;

                var request = new LicensesActivityRequest
            {
                BaseInfo = CreateBaseInfo(client),
                GroupBy = "Feature",
                StartTime = new SlimDateTime()
                {
                    Year = startTime.Year,
                    Month = startTime.Month,
                    Day = startTime.Day                    
                },

                EndTime = new SlimDateTime()
                {
                    Year = endTime.Year,
                    Month = endTime.Month,
                    Day = endTime.Day,
                    Hour = endTime.Hour,
                    Minute = endTime.Minute,
                    Second = endTime.Second
                }
            };

            var response = client.GetLicensesActivityByGroup(request);
            Assert.IsNotNull(response);
            Assert.IsNull(response.Error);
        }

        [TestMethod]
        public void GetTop10UsersOfMostUsedFeaturesInLast30Days()
        {
            var client = new AdminAPIClient();

            var startTime = DateTime.UtcNow.Date.AddDays(-30);
            var endTime = DateTime.UtcNow;

            var request = new LicensesActivityRequest
            {
                BaseInfo = CreateBaseInfo(client),
                GroupBy = "User",
                StartTime = new SlimDateTime()
                {
                    Year = startTime.Year,
                    Month = startTime.Month,
                    Day = startTime.Day
                },

                EndTime = new SlimDateTime()
                {
                    Year = endTime.Year,
                    Month = endTime.Month,
                    Day = endTime.Day,
                    Hour = endTime.Hour,
                    Minute = endTime.Minute,
                    Second = endTime.Second
                }
            };

            var response = client.GetLicensesActivityByGroup(request);
            Assert.IsNotNull(response);
            Assert.IsNull(response.Error);
        }

        [TestMethod]
        public void GetTop10CurrentLongestIdleSessions()
        {
            var client = new AdminAPIClient();

            var request = new CurrentlyConsumedLicensesRequest
            {
                BaseInfo = CreateBaseInfo(client)
            };

            var response = client.GetCurrentlyConsumedLicenses(request);
            Assert.IsNotNull(response);
            Assert.IsNull(response.Error);
        }

        [TestMethod]
        public void GetTop10CurrentLongestUsageSessions()
        {
            var client = new AdminAPIClient();

            var request = new CurrentlyConsumedLicensesRequest
            {
                BaseInfo = CreateBaseInfo(client)
            };

            var response = client.GetCurrentlyConsumedLicenses(request);
            Assert.IsNotNull(response);
            Assert.IsNull(response.Error);
        }

        [TestMethod]
        public void GetLicenseServersStatus()
        {
            var client = new AdminAPIClient();

            var request = new GetLicenseServersRequest
            {
                BaseInfo = CreateBaseInfo(client)
            };

            var response = client.GetLicenseServers(request);
            Assert.IsNotNull(response);
            Assert.IsNull(response.Error);
        }

        #region Private methods
        private RequestBaseInfo CreateBaseInfo(AdminAPIClient client)
        {
            return new RequestBaseInfo
            {
                PagingData = new PagingData
                {
                    StartRecord = 0,
                    NumOfRecord = 10,
                    Sort = new string[] { "value" },
                    Direction = "desc"
                },

                UserLocalSettings = new UserLocalSettings
                {
                    TimezoneStandardName = "UTC",
                    ThousandsSeparator = ",",
                    DecimalSeparator = ".",
                    TimeFormat = "dd/mm/yyyy hh:mm:ss"
                },
                SessionData = new SessionRefresh { Refresh = true, SessionID = GetSessionID(client) }
            };
        }

        private string GetSessionID(AdminAPIClient client)
        {
            LoginFormSettingsResponse response = client.GetLoginFormSettings(new LoginFormSettingsRequest());
            if (response.UserAuthenticationRequired)
            {
                return AdminAPIAuthentication(client, response.ShowWinAuth);
            }
            else//No authentication required
            {
                return string.Empty;
            }
        }

        private static string AdminAPIAuthentication(AdminAPIClient client, bool useWindowsAuthentication)
        {
            UserAuthenticationRequest userAuthenticationRequest = new UserAuthenticationRequest { TrustedAuthentication = useWindowsAuthentication };//Windows authentication 
            if (!useWindowsAuthentication)//OpenLM server authentication 
            {
                userAuthenticationRequest.UserName = UserName;
                userAuthenticationRequest.Password = Password;
            }/* If OpenLM server authentication is required uncheck this code
            else
            {
                userAuthenticationRequest.UserName = UserName;
                userAuthenticationRequest.Password = Password;
                userAuthenticationRequest.TrustedAuthentication = false;
                
            }*/
            UserAuthenticationResponse userAuthenticationResponse = client.PerformUserAuthentication(userAuthenticationRequest);
            if (userAuthenticationResponse.Error != null)
            {
                throw new Exception(userAuthenticationResponse.Error.Message);
            }
            return userAuthenticationResponse.SessionID;
        }
        #endregion
    }
}
